<!-- Amazing to see you contributing to Lemon AI!

Replace this comment with:
  - Description: a description of the change,
  - Issue: the issue # it fixes (if applicable),
  - Dependencies: any dependencies required for this change,

You can find the contribution guidelines here: https://github.com/felixbrock/lemonai-py-client/blob/main/.github/CONTRIBUTING.md
 -->
